Widgets
=============

.. toctree::

    qt_widgets

.. automodule:: clickqt.widgets.basewidget
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.checkbox
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.combobox
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.confirmationwidget
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.datetimeedit
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.filefield
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.filepathfield
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.messagebox
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.multivaluewidget
     :show-inheritance:
     :members:

.. automodule:: clickqt.widgets.numericfields
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.nvaluewidget
    :show-inheritance:
    :members:

.. automodule:: clickqt.widgets.passwordfield
    :show-inheritance:
    :members:
    
.. automodule:: clickqt.widgets.textfield
    :show-inheritance:
    :members:
 
.. automodule:: clickqt.widgets.tuplewidget
    :show-inheritance:
    :members:
